@@ -4,11 +4,10 @@ require 'securerandom'
 module Faker
   class Bitcoin < Base
     class << self
-
       PROTOCOL_VERSIONS = {
         main: 0,
         testnet: 111
-      }
+      }.freeze
 
       def address
         address_for(:main)
@@ -25,22 +24,21 @@ module Faker
         base = alphabet.size
 
         lv = 0
-        str.split('').reverse.each_with_index { |v,i| lv += v.unpack('C')[0] * 256**i }
+        str.split('').reverse.each_with_index { |v, i| lv += v.unpack('C')[0] * 256**i }
 
         ret = ''
-        while lv > 0 do
+        while lv > 0
           lv, mod = lv.divmod(base)
           ret << alphabet[mod]
         end
 
         npad = str.match(/^#{0.chr}*/)[0].to_s.size
-        '1'*npad + ret.reverse
+        '1' * npad + ret.reverse
       end
 
       def address_for(network)
         version = PROTOCOL_VERSIONS.fetch(network)
-        hash = SecureRandom.hex(20)
-        packed = version.chr + [hash].pack("H*")
+        packed = version.chr + Faker::Config.random.bytes(20)
         checksum = Digest::SHA2.digest(Digest::SHA2.digest(packed))[0..3]
         base58(packed + checksum)
       end
