@@ -10,13 +10,12 @@ module Faker
       end
 
       def credit_card_expiry_date
-        ::Date.today + (365 * (rand(4) + 1))
+        ::Date.today + (365 * rand(1..4))
       end
 
       def credit_card_type
         fetch('business.credit_card_types')
       end
     end
-
   end
 end
