@@ -1,35 +1,43 @@
 module Faker
   class Commerce < Base
-
     class << self
       def color
         fetch('color.name')
       end
 
+      def promotion_code(digits = 6)
+        [
+          fetch('commerce.promotion_code.adjective'),
+          fetch('commerce.promotion_code.noun'),
+          Faker::Number.number(digits)
+        ].join
+      end
+
       def department(max = 3, fixed_amount = false)
         num = max if fixed_amount
         num ||= 1 + rand(max)
 
         categories = categories(num)
 
-        if num > 1
-          merge_categories(categories)
-        else
-          categories[0]
-        end
+        return merge_categories(categories) if num > 1
+        categories[0]
       end
 
       def product_name
-        fetch('commerce.product_name.adjective') + ' ' + fetch('commerce.product_name.material') + ' ' + fetch('commerce.product_name.product')
+        "#{fetch('commerce.product_name.adjective')} #{fetch('commerce.product_name.material')} #{fetch('commerce.product_name.product')}"
       end
 
       def material
         fetch('commerce.product_name.material')
       end
 
-      def price(range=0..100.0)
-        random = Random::DEFAULT
-        (random.rand(range) * 100).floor/100.0
+      def price(range = 0..100.0, as_string = false)
+        price = (rand(range) * 100).floor / 100.0
+        if as_string
+          price_parts = price.to_s.split('.')
+          price = price_parts[0] + '.' + price_parts[-1].ljust(2, '0')
+        end
+        price
       end
 
       private
