@@ -1,4 +1,3 @@
-# encoding: utf-8
 module Faker
   class File < Base
     class << self
@@ -11,10 +10,9 @@ module Faker
       end
 
       def file_name(dir = nil, name = nil, ext = nil, directory_separator = '/')
-
-        dir = Faker::Internet::slug unless dir
-        name = Faker::Lorem::word().downcase unless name
-        ext = extension unless ext
+        dir ||= Faker::Internet.slug
+        name ||= Faker::Lorem.word.downcase
+        ext ||= extension
 
         [dir, name].join(directory_separator) + ".#{ext}"
       end
