@@ -1,12 +1,14 @@
 module Faker
   class Finance < Base
-    CREDIT_CARD_TYPES = [ :visa, :mastercard,  :discover, :american_express, :diners_club, :jcb, :switch, :solo, :dankort, :maestro, :forbrugsforeningen, :laser ]
+    CREDIT_CARD_TYPES = %i[visa mastercard discover american_express
+                           diners_club jcb switch solo dankort
+                           maestro forbrugsforeningen laser].freeze
 
     class << self
       def credit_card(*types)
         types = CREDIT_CARD_TYPES if types.empty?
-        type = types.sample
-        template = numerify(fetch("credit_card.#{type}"))
+        type = sample(types)
+        template = numerify(fetch("finance.credit_card.#{type}"))
 
         # calculate the luhn checksum digit
         multiplier = 1
@@ -18,8 +20,7 @@ module Faker
         # last digit must be 10 - the last digit of the sum.
         luhn_digit = (10 - (luhn_sum % 10)) % 10
 
-        template.gsub! 'L', luhn_digit.to_s
-        template
+        template.gsub('L', luhn_digit.to_s)
       end
     end
   end
