@@ -8,6 +8,10 @@ module Faker
       def location
         fetch('pokemon.locations')
       end
+
+      def move
+        fetch('pokemon.moves')
+      end
     end
   end
-end
\ No newline at end of file
+end
