@@ -49,6 +49,14 @@ module Faker
       def distance_measurement
         rand(10..100).to_s + ' ' + fetch('space.distance_measurement')
       end
+
+      def meteorite
+        fetch('space.meteorite')
+      end
+
+      def launch_vehicule
+        fetch('space.launch_vehicule')
+      end
     end
   end
 end
