@@ -1,4 +1,4 @@
-require File.expand_path(File.dirname(__FILE__) + '/test_helper.rb')
+require_relative 'test_helper'
 
 class TestCaCatLocale < Test::Unit::TestCase
   def setup
@@ -24,12 +24,12 @@ class TestCaCatLocale < Test::Unit::TestCase
   end
 
   def test_phone_numbers_start_with_9
-    mobile = Faker::PhoneNumber.phone_number.gsub(/\D/,'')
+    mobile = Faker::PhoneNumber.phone_number.gsub(/\D/, '')
     assert_equal '9', mobile[0]
   end
 
   def test_cell_numbers_start_with_6
-    mobile = Faker::PhoneNumber.cell_phone.gsub(/\D/,'')
+    mobile = Faker::PhoneNumber.cell_phone.gsub(/\D/, '')
     assert_equal '6', mobile[0]
   end
 end
