@@ -1,4 +1,4 @@
-require File.expand_path(File.dirname(__FILE__) + '/test_helper.rb')
+require_relative 'test_helper'
 
 class TestDeAtLocale < Test::Unit::TestCase
   def setup
@@ -14,6 +14,7 @@ class TestDeAtLocale < Test::Unit::TestCase
     assert Faker::Address.state.is_a? String
     assert Faker::Address.state_abbr.is_a? String
     assert Faker::Address.city_name.is_a? String
+    assert Faker::Address.street_root.is_a? String
     assert Faker::Company.suffix.is_a? String
     assert Faker::Company.name.is_a? String
     assert Faker::Internet.free_email.is_a? String
@@ -24,4 +25,8 @@ class TestDeAtLocale < Test::Unit::TestCase
     assert Faker::Name.nobility_title_prefix.is_a? String
     assert Faker::Name.name.is_a? String
   end
+
+  def test_at_default_country
+    assert_equal('Österreich', Faker::Address.default_country)
+  end
 end
