@@ -1,4 +1,4 @@
-require File.expand_path(File.dirname(__FILE__) + '/test_helper.rb')
+require_relative 'test_helper'
 
 class TestEnNzLocale < Test::Unit::TestCase
   def setup
@@ -17,7 +17,7 @@ class TestEnNzLocale < Test::Unit::TestCase
   end
 
   def test_nz_cellphones_start_with_02
-    cellphone = Faker::PhoneNumber.cell_phone.gsub(/\D/,'')
+    cellphone = Faker::PhoneNumber.cell_phone.gsub(/\D/, '')
     assert_equal '0', cellphone[0]
     assert_equal '2', cellphone[1]
   end
@@ -30,4 +30,16 @@ class TestEnNzLocale < Test::Unit::TestCase
     assert Faker::Address.region.is_a? String
     assert Faker::Address.region_abbr.is_a? String
   end
-end
\ No newline at end of file
+
+  def test_team_sport_with_en_nz_locale
+    assert Faker::Team.sport.is_a? String
+  end
+
+  def test_team_names_with_en_nz_locale
+    assert Faker::Team.name.is_a? String
+  end
+
+  def test_university_names_with_en_nz_locale
+    assert Faker::University.name.is_a? String
+  end
+end
