@@ -1,4 +1,4 @@
-require File.expand_path(File.dirname(__FILE__) + '/test_helper.rb')
+require_relative 'test_helper'
 
 class TestEnPakLocale < Test::Unit::TestCase
   def setup
@@ -19,4 +19,8 @@ class TestEnPakLocale < Test::Unit::TestCase
     assert Faker::Internet.domain_suffix.is_a? String
     assert Faker::Company.suffix.is_a? String
   end
+
+  def test_en_pak_default_country
+    assert_match(/\A(Pakistan|Islamic Republic of Pakistan)\z/, Faker::Address.default_country)
+  end
 end
