@@ -1,4 +1,4 @@
-require File.expand_path(File.dirname(__FILE__) + '/test_helper.rb')
+require_relative 'test_helper'
 
 class TestEnUgLocale < Test::Unit::TestCase
   def setup
@@ -12,12 +12,11 @@ class TestEnUgLocale < Test::Unit::TestCase
 
   def test_validity_of_phone_number
     validation_regex = /^((0)|(256)|(\+256))((39)|(41))\d{7}$/
-    assert_match(validation_regex, Faker::PhoneNumber.phone_number.gsub(' ',''))
+    assert_match(validation_regex, Faker::PhoneNumber.phone_number.delete(' '))
   end
 
   def test_validity_of_cell_phone
     validation_regex = /^((0)|(256)|(\+256))((70)|(71)|(72)|(74)|(75)|(77)|(78)|(79))\d{7}$/
-    assert_match(validation_regex, Faker::PhoneNumber.cell_phone.gsub(' ',''))
+    assert_match(validation_regex, Faker::PhoneNumber.cell_phone.delete(' '))
   end
-
-end
\ No newline at end of file
+end
