@@ -1,4 +1,4 @@
-require File.expand_path(File.dirname(__FILE__) + '/test_helper.rb')
+require_relative 'test_helper'
 require 'minitest/mock'
 
 class TestFakerBoolean < Test::Unit::TestCase
