@@ -1,4 +1,4 @@
-require File.dirname(__FILE__) + '/test_helper.rb'
+require_relative 'test_helper'
 
 class TestFakerCode < Test::Unit::TestCase
   def setup
@@ -9,6 +9,14 @@ class TestFakerCode < Test::Unit::TestCase
     assert @tester.npi.match(/[0-9]{10}/)
   end
 
+  def test_deterministic_npi
+    Faker::Config.random = Random.new(42)
+    v = @tester.npi
+    Faker::Config.random = Random.new(42)
+
+    assert v == @tester.npi
+  end
+
   def test_default_isbn_regexp
     assert @tester.isbn.match(/^\d{9}-[\d|X]$/)
   end
@@ -45,6 +53,12 @@ class TestFakerCode < Test::Unit::TestCase
     assert luhn_checksum_valid(@tester.imei)
   end
 
+  def test_sin
+    assert @tester.sin.match(/\d{9}/)
+    assert @tester.sin.length == 9
+    assert luhn_checksum_valid(@tester.sin)
+  end
+
   def luhn_checksum_valid(numbers)
     sum = 0
     i = 0
