@@ -1,4 +1,4 @@
-require File.expand_path(File.dirname(__FILE__) + '/test_helper.rb')
+require_relative 'test_helper'
 
 class TestFakerColor < Test::Unit::TestCase
   def setup
@@ -26,25 +26,29 @@ class TestFakerColor < Test::Unit::TestCase
     end
   end
 
-  def test_single_hsl_color
-    assert @tester.single_hsl_color.between?(0.0, 360.0)
-  end
-
   def test_hsl_color
     @result = @tester.hsl_color
     assert @result.length == 3
 
-    @result.each do |color|
-      assert color.between?(0.0, 360.0)
+    assert @result[0].between?(0, 360)
+
+    if RUBY_VERSION < '2.4.0'
+      assert @result[0].is_a?(Fixnum)
+    else
+      assert @result[0].is_a?(Integer)
     end
+
+    assert @result[1].between?(0.0, 1.0)
+    assert @result[2].between?(0.0, 1.0)
   end
 
   def test_hsla_color
     @result = @tester.hsla_color
     assert @result.length == 4
 
-    @result.each do |color|
-      assert color.between?(0.0, 360.0) || color.between?(0.0, 1.0)
-    end
+    assert @result[0].between?(0, 360)
+    assert @result[1].between?(0.0, 1.0)
+    assert @result[2].between?(0.0, 1.0)
+    assert @result[3].between?(0.0, 1.0)
   end
 end
