@@ -1,7 +1,6 @@
-require File.expand_path(File.dirname(__FILE__) + '/test_helper.rb')
+require_relative 'test_helper'
 
 class TestFakerCommerce < Test::Unit::TestCase
-
   def setup
     @tester = Faker::Commerce
   end
@@ -10,6 +9,14 @@ class TestFakerCommerce < Test::Unit::TestCase
     assert @tester.color.match(/[a-z]+\.?/)
   end
 
+  def test_promotion_code
+    assert @tester.promotion_code.match(/[A-Z][a-z]+[A-Z][a-z]+\d{6}/)
+  end
+
+  def test_promotion_code_should_have_specified_number_of_digits
+    assert @tester.promotion_code(3).match(/[A-Z][a-z]+[A-Z][a-z]+\d{3}/)
+  end
+
   def test_department
     assert @tester.department.match(/[A-Z][a-z]+\.?/)
   end
@@ -25,16 +32,16 @@ class TestFakerCommerce < Test::Unit::TestCase
   def test_department_should_accept_localized_separator
     @old_locales = I18n.config.available_locales
     data = {
-      :faker => {
-        :separator => ' + ',
-        :commerce => {
-          :department => ['Books', 'Movies']
+      faker: {
+        separator: ' + ',
+        commerce: {
+          department: %w[Books Movies]
         }
       }
     }
 
+    I18n.config.available_locales += [:xy]
     I18n.backend.store_translations(:xy, data)
-    I18n.config.available_locales += [ :xy ]
     I18n.with_locale(:xy) do
       assert_match ' + ', @tester.department(2, true)
     end
@@ -74,11 +81,16 @@ class TestFakerCommerce < Test::Unit::TestCase
   end
 
   def test_price_with_srand
-    srand(12345)
+    Faker::Config.random = Random.new(12_345)
     assert_equal 92.96, @tester.price
   end
 
   def test_price_is_float
     assert @tester.price.is_a? Float
   end
+
+  def test_when_as_string_is_true
+    assert @tester.price(0..100.0, true).is_a?(String)
+    assert @tester.price(100..500.0, true).include?('.')
+  end
 end
