@@ -1,4 +1,4 @@
-require File.expand_path(File.dirname(__FILE__) + '/test_helper.rb')
+require_relative 'test_helper'
 
 class TestFakerGameOfThrones < Test::Unit::TestCase
   def setup
@@ -16,4 +16,12 @@ class TestFakerGameOfThrones < Test::Unit::TestCase
   def test_city
     assert @tester.city.match(/\w+/)
   end
+
+  def test_quote
+    assert @tester.quote.match(/\w+/)
+  end
+
+  def test_dragon
+    assert @tester.dragon.match(/\w+/)
+  end
 end
