@@ -1,4 +1,4 @@
-require File.expand_path(File.dirname(__FILE__) + '/test_helper.rb')
+require_relative 'test_helper'
 require 'minitest/mock'
 
 class TestFakerNumber < Test::Unit::TestCase
@@ -16,7 +16,7 @@ class TestFakerNumber < Test::Unit::TestCase
 
     assert @tester.number(10).length == 10
     assert @tester.number(1).length == 1
-    assert @tester.number(0) == ""
+    assert @tester.number(0) == ''
   end
 
   def test_decimal
@@ -26,12 +26,12 @@ class TestFakerNumber < Test::Unit::TestCase
 
   def test_digit
     assert @tester.digit.match(/[0-9]{1}/)
-    assert (1..1000).collect {|i| @tester.digit == "9"}.include?(true)
+    assert((1..1000).collect { |_i| @tester.digit == '9' }.include?(true))
   end
 
   def test_even_distribution
     assert stats = {}
-    assert times = 10000
+    assert times = 10_000
 
     times.times do
       assert num = @tester.digit
@@ -39,11 +39,22 @@ class TestFakerNumber < Test::Unit::TestCase
       assert stats[num] += 1
     end
 
-    stats.each do |k, v|
+    stats.each do |_k, v|
       assert_in_delta 10.0, 100.0 * v / times, 2.0
     end
   end
 
+  def test_normal
+    n = 10_000
+    values = Array.new(n) { @tester.normal(150.0, 100.0) }
+    mean = values.reduce(:+) / n.to_f
+    variance = values.inject(0) { |var, value| var + (value - mean)**2 } / (n - 1).to_f
+    std_dev = Math.sqrt variance
+
+    assert_in_delta 150.0, mean, 5.0
+    assert_in_delta 100.0, std_dev, 3.0
+  end
+
   def test_between
     100.times do
       random_number = @tester.between(-50, 50)
@@ -95,12 +106,12 @@ class TestFakerNumber < Test::Unit::TestCase
     @tester.stub :digit, 0 do
       assert_equal '0', @tester.number(1)
       100.times do
-        assert_match (/^[1-9]0/), @tester.number(2)
+        assert_match(/^[1-9]0/, @tester.number(2))
       end
 
-      assert_equal '0.0', @tester.decimal(1,1)
+      assert_equal '0.0', @tester.decimal(1, 1)
       100.times do
-        assert_match (/^0\.0[1-9]/), @tester.decimal(1,2)
+        assert_match(/^0\.0[1-9]/, @tester.decimal(1, 2))
       end
     end
   end
