@@ -1,4 +1,4 @@
-require File.expand_path(File.dirname(__FILE__) + '/test_helper.rb')
+require_relative 'test_helper'
 
 class TestFakerPokemon < Test::Unit::TestCase
   def setup
@@ -13,4 +13,7 @@ class TestFakerPokemon < Test::Unit::TestCase
     assert @tester.location.match(/\w+/)
   end
 
+  def test_move
+    assert @tester.move.match(/\w+/)
+  end
 end
