@@ -1,10 +1,9 @@
-require File.expand_path(File.dirname(__FILE__) + '/test_helper.rb')
+require_relative 'test_helper'
 
 class TestFakerSlackEmoji < Test::Unit::TestCase
-
   def setup
     @tester = Faker::SlackEmoji
-    @emoticon_regex= /^:([\w-]+):$/
+    @emoticon_regex = /^:([\w-]+):$/
   end
 
   def test_people
@@ -42,4 +41,4 @@ class TestFakerSlackEmoji < Test::Unit::TestCase
   def test_emoji
     assert @tester.emoji.match(@emoticon_regex)
   end
-end
\ No newline at end of file
+end
