@@ -1,4 +1,4 @@
-require File.expand_path(File.dirname(__FILE__) + '/test_helper.rb')
+require_relative 'test_helper'
 
 class TestFakerSpace < Test::Unit::TestCase
   def setup
@@ -53,4 +53,11 @@ class TestFakerSpace < Test::Unit::TestCase
     assert @tester.distance_measurement.match(/(\w+\.? ?){2,3}/)
   end
 
+  def test_meteorite
+    assert @tester.meteorite.match(/(\w+\.? ?){2,3}/)
+  end
+
+  def test_launch_vehicule
+    assert @tester.launch_vehicule.match(/(\w+\.? ?){2,3}/)
+  end
 end
