@@ -1,7 +1,6 @@
-require File.expand_path(File.dirname(__FILE__) + '/test_helper.rb')
+require_relative 'test_helper'
 
 class TestFakerTeam < Test::Unit::TestCase
-
   def setup
     @tester = Faker::Team
   end
@@ -21,5 +20,4 @@ class TestFakerTeam < Test::Unit::TestCase
   def test_sport
     assert @tester.sport.match(/(\w+){1}/)
   end
-
 end
