@@ -1,4 +1,4 @@
-require File.expand_path(File.dirname(__FILE__) + '/test_helper.rb')
+require_relative 'test_helper'
 
 class TestFiLocale < Test::Unit::TestCase
   def setup
@@ -24,6 +24,13 @@ class TestFiLocale < Test::Unit::TestCase
     assert Faker::Address.state.is_a? String
   end
 
+  def test_fi_invoice_methods
+    assert Faker::Invoice.creditor_reference.is_a? String
+    assert Faker::Invoice.reference.is_a? String
+    assert Faker::Invoice.reference('515141803475128').is_a? String
+    assert Faker::Invoice.reference('515141803475128#') == '5151418034751285'
+  end
+
   def test_fi_phone_number
     assert_match(/0\d{2}[\-\s]?\d{6}/, Faker::PhoneNumber.cell_phone)
     assert_match(/\d{2,3}[\s\-]?\d{5,6}/, Faker::PhoneNumber.phone_number)
