@@ -1,8 +1,7 @@
-require File.expand_path(File.dirname(__FILE__) + '/test_helper.rb')
+require_relative 'test_helper'
 
-LoadedYaml = ['en', 'en-BORK'].inject({}) do |h, locale|
+LoadedYaml = ['en', 'en-BORK'].each_with_object({}) do |locale, h|
   h[locale] = YAML.load_file(File.expand_path(File.dirname(__FILE__) + "/../lib/locales/#{locale}.yml"))[locale]['faker']
-  h
 end
 
 class TestLocale < Test::Unit::TestCase
@@ -26,18 +25,18 @@ class TestLocale < Test::Unit::TestCase
 
   def test_locale_override_when_calling_translate
     Faker::Config.locale = 'en-BORK'
-    assert_equal Faker::Base.translate('faker.lorem.words', :locale => :en).first, LoadedYaml['en']['lorem']['words'].first
+    assert_equal Faker::Base.translate('faker.separator', locale: :en), LoadedYaml['en']['separator']
   end
 
   def test_translation_fallback
     Faker::Config.locale = 'en-BORK'
     assert_nil LoadedYaml['en-BORK']['name']
-    assert_equal Faker::Base.translate('faker.name.first_name').first, LoadedYaml['en']['name']['first_name'].first
+    assert_equal Faker::Base.translate('faker.separator'), LoadedYaml['en']['separator']
   end
 
   def test_regex
     Faker::Config.locale = 'en-GB'
-    re = /[A-PR-UWYZ][A-HK-Y]?[0-9][ABEHMNPRVWXY0-9]? {1,2}[0-9][ABD-HJLN-UW-Z]{2}/
+    re = /[A-PR-UWYZ]([A-HK-Y][0-9][ABEHMNPRVWXY0-9]?|[0-9][ABCDEFGHJKPSTUW0-9]?) [0-9][ABD-HJLNP-UW-Z]{2}/
     assert re.match(result = Faker::Address.postcode), "#{result} didn't match #{re}"
   end
 
