@@ -1,4 +1,4 @@
-require File.expand_path(File.dirname(__FILE__) + '/test_helper.rb')
+require_relative 'test_helper'
 
 class TestSVLocale < Test::Unit::TestCase
   def setup
@@ -15,6 +15,7 @@ class TestSVLocale < Test::Unit::TestCase
     assert Faker::Name.first_name_men.is_a? String
     assert Faker::Name.first_name_women.is_a? String
     assert Faker::Name.last_name.is_a? String
+    assert Faker::Name.prefix.is_a? String
   end
 
   def test_sv_phone_number
@@ -22,7 +23,7 @@ class TestSVLocale < Test::Unit::TestCase
     assert Faker::PhoneNumber.phone_number.match(/^\d{4}[\s\-]?\d{4,6}$/)
   end
 
-  def test_sv_post_code 
+  def test_sv_post_code
     assert Faker::Address.postcode.match(/^[\d]{5}$/)
   end
 end
